var __defProp = Object.defineProperty;
var __markAsModule = (target) => __defProp(target, "__esModule", {value: true});
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, {get: all[name], enumerable: true});
};

// src/reporter.ts
__markAsModule(exports);
__export(exports, {
  default: () => report
});

// src/formatMessage.ts
function formatMessage(filePath, result) {
  const {ruleId, line, column, message} = result;
  let output = `file=${filePath}`;
  if (line) {
    output += `,line=${line}`;
  }
  if (column) {
    output += `,col=${column}`;
  }
  output += `::[${ruleId}] ${message}`;
  return output;
}

// src/wrapInGroup.ts
var groupSet = new Set();
var startGroupOnce = (groupName) => {
  if (!groupSet.has(groupName)) {
    console.log(`::group::${groupName}`);
    groupSet.add(groupName);
  }
};
function wrapInGroup(groupName, messages, cb) {
  for (const message of messages) {
    startGroupOnce(groupName);
    cb(message);
  }
  if (groupSet.has(groupName)) {
    console.log("::endgroup::");
  }
}

// src/reporter.ts
function getRelativePath(path) {
  const {GITHUB_WORKSPACE} = process.env;
  if (GITHUB_WORKSPACE) {
    return path.replace(`${GITHUB_WORKSPACE}/`, "");
  }
  return path;
}
function report(results) {
  for (const result of results) {
    const {filePath, messages} = result;
    const relFilePath = getRelativePath(filePath);
    wrapInGroup(relFilePath, messages, (message) => {
      if (!message.ruleId) {
        return;
      }
      switch (message.severity) {
        case 1:
          console.log("::warning", formatMessage(relFilePath, message));
          break;
        case 2:
          console.log("::error", formatMessage(relFilePath, message));
          break;
        default:
          break;
      }
    });
  }
}
module.exports = report;
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {});
